@@ -31,6 +31,11 @@
 #' country given as a ISO 639-1 (2 letter) country code.
 #' @param networkKey Filters network UUID associated to a dataset.
 #' @param doi DOI of the dataset.
+#' @param installationKey Filters datasets by their installation UUID key.
+#' @param endpointType Filters datasets by their endpoint type. 
+#' Available values : EML, FEED, WFS, WMS, TCS_RDF, TCS_XML, DWC_ARCHIVE, DIGIR, 
+#' DIGIR_MANIS, TAPIR, BIOCASE, BIOCASE_XML_ARCHIVE, OAI_PMH, COLDP, 
+#' CAMTRAP_DP, BIOM_1_0, BIOM_2_1, ACEF, TEXT_TREE, OTHER
 #' @param facet A facet name used to retrieve the most frequent values for a field.
 #' @param facetLimit Facet parameters allow paging requests using the parameters 
 #' facetOffset and facetLimit.
@@ -92,6 +97,7 @@
 #' dataset_search(projectId = "GRIIS;BID-AF2020-140-REG") 
 #' dataset_search(hostingCountry = "NO;SE")
 #' dataset_search(doi="10.15468/aomfnb;10.15468/igasai")
+#' dataset_search(installationKey = "d209e552-7e6e-4840-b13c-c0596ef36e55")
 #' 
 #' # multiple filters
 #' dataset_search(license = "CC0_1_0",subtype = "TAXONOMIC_AUTHORITY")
@@ -120,7 +126,9 @@ dataset_search <- function(query = NULL,
                            projectId = NULL,
                            hostingCountry = NULL,
                            networkKey = NULL,
-                           doi = NULL, 
+                           doi = NULL,
+                           installationKey = NULL,
+                           endpointType = NULL,
                            facet = NULL,
                            facetLimit = NULL, 
                            facetOffset = NULL, 
@@ -129,8 +137,7 @@ dataset_search <- function(query = NULL,
                            limit = 100,
                            start = NULL,
                            description = FALSE,
-                           curlopts = list()) {
-
+                           curlopts = list(http_version=2)) {
   assert(query,"character")
   assert(type,"character")
   assert(subtype,"character")
@@ -144,6 +151,8 @@ dataset_search <- function(query = NULL,
   assert(hostingCountry,"character")
   assert(networkKey,"character")
   assert(doi,"character")
+  assert(installationKey,"character")
+  assert(endpointType,"character")
   assert(facet,"character")
   
   # args with single value 
@@ -155,7 +164,7 @@ dataset_search <- function(query = NULL,
                     facetOffset=facetOffset,
                     facetMincount=facetMincount,
                     facetMultiselect=facetMultiselect
-                    )))
+    )))
   
   args <- rgbif_compact(c(
     args,
@@ -172,14 +181,17 @@ dataset_search <- function(query = NULL,
     convmany(hostingCountry),
     convmany(networkKey),
     convmany(doi),
+    convmany(installationKey),
+    convmany(endpointType),
     convmany(facet)
   ))
   
   url <- paste0(gbif_base(), '/dataset/search')
   tt <- gbif_GET(url, args, FALSE, curlopts)
+  
   # metadata
   meta <- tt[c('offset','limit','endOfRecords','count')]
-
+  
   # facets
   facets <- tt$facets
   if (!length(facets) == 0) {
