@@ -61,7 +61,8 @@
 #' name_suggest(q='Puma', limit=200, curlopts = list(verbose=TRUE))
 #' }
 name_suggest <- function(q=NULL, datasetKey=NULL, rank=NULL, fields=NULL,
-                         start=NULL, limit=100, curlopts = list()) {
+                         start=NULL, limit=100, 
+                         curlopts = list(http_version = 2)) {
   
   if(limit > 100) { warning("Max limit is 100."); limit <- 100} 
   url <- paste0(gbif_base(), '/species/suggest')
