@@ -1,14 +1,14 @@
 context("name_parse")
 
 test_that("returns the correct class", {
-  vcr::use_cassette("name_parse", {
-    
-    tt <- name_parse(scientificname = 'x Agropogon littoralis')
-    uu <- name_parse(c('Arrhenatherum elatius var. elatius',
-                       'Secale cereale subsp. cereale', 'Secale cereale ssp. cereale',
-                       'Vanessa atalanta (Linnaeus, 1758)'))
-  }, preserve_exact_body_bytes = TRUE)
+  skip_on_cran()
+  skip_on_ci()
   
+  tt <- name_parse(scientificname = 'x Agropogon littoralis')
+  uu <- name_parse(c('Arrhenatherum elatius var. elatius',
+                     'Secale cereale subsp. cereale', 'Secale cereale ssp. cereale',
+                     'Vanessa atalanta (Linnaeus, 1758)'))
+
   expect_is(tt, "data.frame")
   expect_is(uu, "data.frame")
   expect_is(uu$scientificname, "character")
