@@ -25,7 +25,6 @@ test_that("occ_download: real requests work", {
   expect_equal(attr(zzz, "user"), Sys.getenv("GBIF_USER"))
   expect_equal(attr(zzz, "email"),Sys.getenv("GBIF_EMAIL"))
   expect_equal(attr(zzz, "format"), "DWCA")
-  expect_is(attr(zzz,"doi"),"character")
   expect_is(attr(zzz,"citation"),"character")
   expect_is(attr(zzz,"downloadLink"),"character")
   expect_output(print.occ_download(zzz),"<<gbif download>>")
@@ -52,9 +51,7 @@ test_that("occ_download: real requests work", {
   expect_is(attr(x, "created"),"character")
   expect_is(attr(x, "status"),"character")
   expect_is(attr(x, "downloadLink"),"character")
-  expect_is(attr(x, "doi"), "character")
   expect_is(attr(x, "citation"), "character")
-  expect_is(attr(x,"doi"),"character")
   expect_is(attr(x,"citation"),"character")
   expect_is(attr(x,"downloadLink"),"character")
   expect_output(print.occ_download(x),"<<gbif download>>")
@@ -70,7 +67,6 @@ test_that("occ_download: real requests work", {
   expect_equal(attr(z, "user"), Sys.getenv("GBIF_USER"))
   expect_equal(attr(z, "email"), Sys.getenv("GBIF_EMAIL"))
   expect_equal(attr(z, "format"), "SPECIES_LIST")
-  expect_is(attr(z,"doi"),"character")
   expect_is(attr(z,"downloadLink"),"character")
   expect_is(attr(z,"citation"),"character")
   expect_output(print.occ_download(z),"<<gbif download>>")
@@ -102,7 +98,6 @@ test_that("occ_download: real requests work", {
   expect_equal(attr(ccc, "user"), Sys.getenv("GBIF_USER"))
   expect_equal(attr(ccc, "email"), Sys.getenv("GBIF_EMAIL"))
   expect_equal(attr(ccc, "format"), "SIMPLE_CSV")
-  expect_is(attr(ccc,"doi"),"character")
   expect_is(attr(ccc,"citation"),"character")
   expect_is(attr(ccc,"downloadLink"),"character")
   expect_output(print.occ_download(ccc),"<<gbif download>>")
@@ -123,7 +118,6 @@ test_that("occ_download: real requests work", {
   expect_equal(attr(vvv, "user"), Sys.getenv("GBIF_USER"))
   expect_equal(attr(vvv, "email"), Sys.getenv("GBIF_EMAIL"))
   expect_equal(attr(vvv, "format"), "SIMPLE_CSV")
-  expect_is(attr(vvv,"doi"),"character")
   expect_is(attr(vvv,"citation"),"character")
   expect_is(attr(vvv,"downloadLink"),"character")
   expect_output(print.occ_download(vvv),"<<gbif download>>")
@@ -144,7 +138,6 @@ test_that("occ_download: real requests work", {
   expect_equal(attr(ooo, "user"), Sys.getenv("GBIF_USER"))
   expect_equal(attr(ooo, "email"), Sys.getenv("GBIF_EMAIL"))
   expect_equal(attr(ooo, "format"), "SIMPLE_CSV")
-  expect_is(attr(ooo,"doi"),"character")
   expect_is(attr(ooo,"citation"),"character")
   expect_is(attr(ooo,"downloadLink"),"character")
   expect_output(print.occ_download(ooo),"<<gbif download>>")
@@ -165,7 +158,6 @@ test_that("occ_download: real requests work", {
   expect_equal(attr(sss, "user"), Sys.getenv("GBIF_USER"))
   expect_equal(attr(sss, "email"), Sys.getenv("GBIF_EMAIL"))
   expect_equal(attr(sss, "format"), "SIMPLE_CSV")
-  expect_is(attr(sss,"doi"),"character")
   expect_is(attr(sss,"citation"),"character")
   expect_is(attr(sss,"downloadLink"),"character")
   expect_output(print.occ_download(sss),"<<gbif download>>")
@@ -185,7 +177,6 @@ test_that("occ_download: real requests work", {
   expect_equal(attr(ddd, "user"), Sys.getenv("GBIF_USER"))
   expect_equal(attr(ddd, "email"), Sys.getenv("GBIF_EMAIL"))
   expect_equal(attr(ddd, "format"), "SIMPLE_CSV")
-  expect_is(attr(ddd,"doi"),"character")
   expect_is(attr(ddd,"citation"),"character")
   expect_is(attr(ddd,"downloadLink"),"character")
   expect_output(print.occ_download(ddd),"<<gbif download>>")
