@@ -41,30 +41,10 @@ test_that("wkt_parse", {
   expect_equal(length(strextracta(aa, ",")), 4)
 
   # geom_big=axe
-  bb <- wkt_parse(wkt, geom_big = "axe")
-  expect_is(bb, "character")
-  expect_equal(length(bb), 4)
-  for (i in bb) expect_is(i, "character")
-  for (i in bb) expect_match(i, "POLYGON")
-
-  # geom_big=axe, geom_size=60
-  cc <- wkt_parse(wkt, geom_big = "axe", geom_size = 60)
-  expect_is(cc, "character")
-  expect_equal(length(cc), 1)
-  for (i in cc) expect_is(i, "character")
-  for (i in cc) expect_match(i, "POLYGON")
-
-  # geom_big=axe, geom_size=5
-  dd <- wkt_parse(wkt, geom_big = "axe", geom_size = 5)
-  expect_is(dd, "character")
-  expect_equal(length(dd), 50)
-  for (i in dd) expect_is(i, "character")
-  for (i in dd) expect_match(i, "POLYGON")
+  expect_warning(wkt_parse(wkt, geom_big = "axe"))
 })
 
 test_that("wkt_parse fails well", {
-  expect_error(wkt_parse(wkt), "missing")
-  expect_error(wkt_parse(wkt, 5), "must be one of")
   expect_error(wkt_parse(wkt, "bbox", geom_size = "adf"), "must be of class")
   expect_error(wkt_parse(wkt, "bbox", geom_n = "adf"), "must be of class")
 })
